==> trilinos_12.14.1.orig.tar.gz: Trilinos-trilinos-release-12-14-1/packages/seacas/libraries/suplib/numeql.f <==
C Copyright(C) 2009-2017 National Technology & Engineering Solutions
C of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
C NTESS, the U.S. Government retains certain rights in this software.
C         
C Redistribution and use in source and binary forms, with or without
C modification, are permitted provided that the following conditions are
C met:
C 
C     * Redistributions of source code must retain the above copyright
C       notice, this list of conditions and the following disclaimer.
C 
C     * Redistributions in binary form must reproduce the above
C       copyright notice, this list of conditions and the following
C       disclaimer in the documentation and/or other materials provided
C       with the distribution.
C 
C     * Neither the name of NTESS nor the names of its
C       contributors may be used to endorse or promote products derived
C       from this software without specific prior written permission.
C 
C THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
C "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
C LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
C A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
C OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
C SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
C LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
C DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
C THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
C (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
C OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

C=======================================================================
      INTEGER FUNCTION NUMEQL (TORF, LENLST, LOGLST)
C=======================================================================
C$Id: numeql.f,v 1.2 2009/03/25 12:46:02 gdsjaar Exp $
C$Log: numeql.f,v $
CRevision 1.2  2009/03/25 12:46:02  gdsjaar
CAdd copyright and license notice to all files.
C
CRevision 1.1.1.1  1990/08/14 16:15:50  gdsjaar
CTesting
C
c Revision 1.1  90/08/14  16:15:49  gdsjaar
c Initial revision
c 
c Revision 1.1  90/08/09  13:39:40  gdsjaar
c Initial revision
c 

C   --*** NUMEQL *** (ETCLIB) Count number of occurances of logical in list
C   --   Written by Amy Gilkey - revised 12/21/87
C   --
C   --NUMEQL returns the number of times the given logical occurs in a list
C   --of logicals.
C   --
C   --Parameters:
C   --   TORF - IN - the logical to be counted
C   --   LENLST - IN - the number of logicals in the list
C   --   LOGLST - IN - the list of logicals to be searched

      LOGICAL TORF
      INTEGER LENLST
      LOGICAL LOGLST(*)

      NUMEQL = 0
      DO 10 I = 1, LENLST
         IF (TORF .EQV. LOGLST(I)) NUMEQL = NUMEQL + 1
   10 CONTINUE

      RETURN
      END

==> trilinos_12.18.1.orig.tar.gz: Trilinos-trilinos-release-12-18-1/packages/seacas/libraries/suplib/numeql.f <==
C Copyright(C) 2009-2017 National Technology & Engineering Solutions
C of Sandia, LLC (NTESS).  Under the terms of Contract DE-NA0003525 with
C NTESS, the U.S. Government retains certain rights in this software.
C
C Redistribution and use in source and binary forms, with or without
C modification, are permitted provided that the following conditions are
C met:
C
C     * Redistributions of source code must retain the above copyright
C       notice, this list of conditions and the following disclaimer.
C
C     * Redistributions in binary form must reproduce the above
C       copyright notice, this list of conditions and the following
C       disclaimer in the documentation and/or other materials provided
C       with the distribution.
C
C     * Neither the name of NTESS nor the names of its
C       contributors may be used to endorse or promote products derived
C       from this software without specific prior written permission.
C
C THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS
C "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT
C LIMITED TO, THE IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR
C A PARTICULAR PURPOSE ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT
C OWNER OR CONTRIBUTORS BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL,
C SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT
C LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
C DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
C THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
C (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE
C OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.

C=======================================================================
      INTEGER FUNCTION NUMEQL (TORF, LENLST, LOGLST)
C=======================================================================
C$Id: numeql.f,v 1.2 2009/03/25 12:46:02 gdsjaar Exp $
C$Log: numeql.f,v $
CRevision 1.2  2009/03/25 12:46:02  gdsjaar
CAdd copyright and license notice to all files.
C
CRevision 1.1.1.1  1990/08/14 16:15:50  gdsjaar
CTesting
C
c Revision 1.1  90/08/14  16:15:49  gdsjaar
c Initial revision
c
c Revision 1.1  90/08/09  13:39:40  gdsjaar
c Initial revision
c

C   --*** NUMEQL *** (ETCLIB) Count number of occurrences of logical in list
C   --   Written by Amy Gilkey - revised 12/21/87
C   --
C   --NUMEQL returns the number of times the given logical occurs in a list
C   --of logicals.
C   --
C   --Parameters:
C   --   TORF - IN - the logical to be counted
C   --   LENLST - IN - the number of logicals in the list
C   --   LOGLST - IN - the list of logicals to be searched

      LOGICAL TORF
      INTEGER LENLST
      LOGICAL LOGLST(*)

      NUMEQL = 0
      DO 10 I = 1, LENLST
         IF (TORF .EQV. LOGLST(I)) NUMEQL = NUMEQL + 1
   10 CONTINUE

      RETURN
      END
